"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommentsTextArea = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importDefault(require("react"));
const react_mentions_1 = require("react-mentions");
const ide_components_1 = require("@opensumi/ide-components");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const common_1 = require("../common");
const comments_body_1 = require("./comments-body");
const comments_module_less_1 = tslib_1.__importDefault(require("./comments.module.less"));
const mentions_style_1 = require("./mentions.style");
const defaultTrigger = '@';
const defaultMarkup = '@[__display__](__id__)';
const defaultDisplayTransform = (id, display) => `@${display}`;
exports.CommentsTextArea = react_1.default.forwardRef((props, ref) => {
    const { focusDelay = 0, autoFocus = false, placeholder = '', onFocus, onBlur, onChange, maxRows = 10, minRows = 2, value, initialHeight, dragFiles, } = props;
    const [index, setIndex] = react_1.default.useState(0);
    const commentsFeatureRegistry = (0, ide_core_browser_1.useInjectable)(common_1.ICommentsFeatureRegistry);
    const inputRef = react_1.default.useRef(null);
    const mentionsRef = react_1.default.useRef(null);
    const itemRef = react_1.default.useRef(null);
    // make `ref` to input works
    react_1.default.useImperativeHandle(ref, () => inputRef.current);
    const handleFileSelect = react_1.default.useCallback(async (event) => {
        var _a;
        event.stopPropagation();
        event.preventDefault();
        const files = (_a = event.dataTransfer) === null || _a === void 0 ? void 0 : _a.files; // FileList object.
        if (files && dragFiles) {
            await dragFiles(files);
        }
        if (inputRef.current) {
            inputRef.current.focus();
            selectLastPosition(inputRef.current.value);
        }
    }, [dragFiles]);
    const handleDragOver = react_1.default.useCallback((event) => {
        event.stopPropagation();
        event.preventDefault();
        event.dataTransfer.dropEffect = 'copy';
    }, []);
    const selectLastPosition = react_1.default.useCallback((value) => {
        const textarea = inputRef.current;
        if (textarea) {
            const position = value.toString().length;
            textarea.setSelectionRange(position, position);
        }
    }, []);
    react_1.default.useEffect(() => {
        var _a;
        const textarea = inputRef.current;
        if (!textarea) {
            return;
        }
        if (initialHeight && textarea.style) {
            textarea.style.height = initialHeight;
        }
        if (focusDelay) {
            setTimeout(() => {
                textarea.focus({
                    preventScroll: true,
                });
            }, focusDelay);
        }
        // auto set last selection
        selectLastPosition(value);
        function handleMouseWheel(event) {
            var _a, _b, _c;
            const target = event.target;
            if (target) {
                if (
                // 当前文本框出现滚动时，防止被编辑器滚动拦截，阻止冒泡
                (target.nodeName.toUpperCase() === 'TEXTAREA' && target.scrollHeight > target.clientHeight) ||
                    // 当是在弹出的提及里滚动，防止被编辑器滚动拦截，阻止冒泡
                    target.nodeName.toUpperCase() === 'UL' ||
                    ((_a = target.parentElement) === null || _a === void 0 ? void 0 : _a.nodeName.toUpperCase()) === 'UL' ||
                    ((_c = (_b = target.parentElement) === null || _b === void 0 ? void 0 : _b.parentElement) === null || _c === void 0 ? void 0 : _c.nodeName.toUpperCase()) === 'UL') {
                    event.stopPropagation();
                }
            }
        }
        (_a = mentionsRef.current) === null || _a === void 0 ? void 0 : _a.addEventListener('mousewheel', handleMouseWheel, true);
        return () => {
            var _a;
            (_a = mentionsRef.current) === null || _a === void 0 ? void 0 : _a.removeEventListener('mousewheel', handleMouseWheel, true);
        };
    }, []);
    react_1.default.useEffect(() => {
        if (index === 0) {
            setTimeout(() => {
                var _a;
                (_a = inputRef.current) === null || _a === void 0 ? void 0 : _a.focus({
                    preventScroll: true,
                });
            }, focusDelay);
            selectLastPosition(value);
        }
    }, [index]);
    const style = react_1.default.useMemo(() => (0, mentions_style_1.getMentionBoxStyle)({
        minRows,
        maxRows,
    }), [minRows, maxRows]);
    const mentionsOptions = react_1.default.useMemo(() => commentsFeatureRegistry.getMentionsOptions(), [commentsFeatureRegistry]);
    const providerData = react_1.default.useCallback(async (query, callback) => {
        if (mentionsOptions.providerData) {
            const data = await mentionsOptions.providerData(query);
            callback(data);
        }
        else {
            callback([]);
        }
    }, [mentionsOptions]);
    return (react_1.default.createElement("div", { className: comments_module_less_1.default.textarea_container },
        react_1.default.createElement(ide_components_1.Tabs, { mini: true, value: index, onChange: (index) => setIndex(index), tabs: [(0, ide_core_browser_1.localize)('comments.thread.textarea.write'), (0, ide_core_browser_1.localize)('comments.thread.textarea.preview')] }),
        react_1.default.createElement("div", null, index === 0 ? (react_1.default.createElement("div", { ref: mentionsRef },
            react_1.default.createElement(react_mentions_1.MentionsInput, { autoFocus: autoFocus, onDragOver: handleDragOver, onDrop: handleFileSelect, inputRef: inputRef, 
                // in react 18, the type of ref is changed to LegacyRef<ClassComponent>
                // but actually it is working pass a dom element ref
                ref: itemRef, value: value, placeholder: placeholder, onChange: onChange, onFocus: onFocus, onBlur: onBlur, style: style },
                react_1.default.createElement(react_mentions_1.Mention, { markup: mentionsOptions.markup || defaultMarkup, renderSuggestion: mentionsOptions.renderSuggestion, trigger: defaultTrigger, data: providerData, displayTransform: mentionsOptions.displayTransform || defaultDisplayTransform })))) : (react_1.default.createElement("div", { className: comments_module_less_1.default.textarea_preview },
            react_1.default.createElement(comments_body_1.CommentsBody, { body: value }))))));
});
//# sourceMappingURL=comments-textarea.view.js.map