"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommentsBrowserContribution = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const next_1 = require("@opensumi/ide-core-browser/lib/menu/next");
const browser_1 = require("@opensumi/ide-editor/lib/browser");
const ide_main_layout_1 = require("@opensumi/ide-main-layout");
const common_1 = require("../common");
const tree_model_service_1 = require("./tree/tree-model.service");
let CommentsBrowserContribution = class CommentsBrowserContribution extends ide_core_browser_1.Disposable {
    onStart() {
        this.registerCommentsFeature();
        this.listenToCreateCommentsPanel();
        this.commentsService.init();
    }
    get panelBadge() {
        const length = this.commentsService.commentsThreads.length;
        return length ? length + '' : '';
    }
    registerCommands(registry) {
        registry.registerCommand({
            id: common_1.CollapseId,
            label: '%comments.panel.action.collapse%',
            iconClass: (0, ide_core_browser_1.getIcon)('collapse-all'),
        }, {
            execute: () => {
                this.commentModelService.collapsedAll();
            },
        });
        registry.registerCommand({
            id: common_1.CloseThreadId,
            label: '%comments.thread.action.close%',
            iconClass: (0, ide_core_browser_1.getIcon)('up'),
        }, {
            execute: (threadTitle) => {
                const { thread, widget } = threadTitle;
                if (!thread.comments.length) {
                    thread.dispose();
                }
                else {
                    if (widget.isShow) {
                        widget.toggle();
                    }
                }
            },
        });
        registry.registerCommand({ id: common_1.SwitchCommandReaction }, {
            execute: (payload) => {
                this.eventBus.fire(new common_1.CommentReactionClick(payload));
            },
        });
    }
    registerMenus(registry) {
        registry.registerMenuItem(next_1.MenuId.CommentsCommentThreadTitle, {
            command: common_1.CloseThreadId,
            group: 'inline',
            order: Number.MAX_SAFE_INTEGER,
        });
    }
    registerToolbarItems(registry) {
        registry.registerItem({
            id: common_1.CollapseId,
            viewId: common_1.CommentPanelId,
            command: common_1.CollapseId,
            tooltip: (0, ide_core_browser_1.localize)('comments.panel.action.collapse'),
        });
    }
    registerCommentsFeature() {
        this.contributions.getContributions().forEach((contribution, index) => {
            this.addDispose(this.commentsService.registerCommentRangeProvider(`contribution_${index}`, {
                getCommentingRanges: (documentModel) => contribution.provideCommentingRanges(documentModel),
            }));
            if (contribution.registerCommentsFeature) {
                contribution.registerCommentsFeature(this.commentsFeatureRegistry);
            }
        });
    }
    /**
     * 因为大多数情况下没有评论，所以默认先不注册底部面板
     * 在第一次创建 thread 的时候再创建底部面板
     * @memberof CommentsBrowserContribution
     */
    listenToCreateCommentsPanel() {
        if (this.commentsFeatureRegistry.getCommentsPanelOptions().defaultShow) {
            this.commentsService.registerCommentPanel();
        }
        else {
            ide_core_browser_1.Event.once(this.commentsService.onThreadsCreated)(() => {
                this.commentsService.registerCommentPanel();
            });
        }
        this.addDispose(ide_core_browser_1.Event.debounce(this.commentsService.onThreadsChanged, () => { }, 100)(() => {
            const handler = this.layoutService.getTabbarHandler(common_1.CommentPanelId);
            handler === null || handler === void 0 ? void 0 : handler.setBadge(this.panelBadge);
        }, this));
    }
    registerEditorFeature(registry) {
        registry.registerEditorFeatureContribution({
            contribute: (editor) => this.commentsService.handleOnCreateEditor(editor),
            provideEditorOptionsForUri: async (uri) => {
                const ranges = await this.commentsService.getContributionRanges(uri);
                // 说明当前 uri 可以评论
                if (ranges.length) {
                    return {
                        // 让编辑器的 lineDecorationsWidth 宽一点，以便放下评论 icon
                        lineDecorationsWidth: 25,
                        lineNumbersMinChars: 5,
                    };
                }
                else {
                    return {};
                }
            },
        });
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(common_1.ICommentsService),
    tslib_1.__metadata("design:type", Object)
], CommentsBrowserContribution.prototype, "commentsService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_main_layout_1.IMainLayoutService),
    tslib_1.__metadata("design:type", Object)
], CommentsBrowserContribution.prototype, "layoutService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(common_1.ICommentsFeatureRegistry),
    tslib_1.__metadata("design:type", Object)
], CommentsBrowserContribution.prototype, "commentsFeatureRegistry", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(common_1.CommentsContribution),
    tslib_1.__metadata("design:type", Object)
], CommentsBrowserContribution.prototype, "contributions", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.IEventBus),
    tslib_1.__metadata("design:type", Object)
], CommentsBrowserContribution.prototype, "eventBus", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(tree_model_service_1.CommentModelService),
    tslib_1.__metadata("design:type", tree_model_service_1.CommentModelService)
], CommentsBrowserContribution.prototype, "commentModelService", void 0);
CommentsBrowserContribution = tslib_1.__decorate([
    (0, ide_core_browser_1.Domain)(ide_core_browser_1.ClientAppContribution, browser_1.BrowserEditorContribution, ide_core_browser_1.CommandContribution, ide_core_browser_1.TabBarToolbarContribution, next_1.MenuContribution)
], CommentsBrowserContribution);
exports.CommentsBrowserContribution = CommentsBrowserContribution;
//# sourceMappingURL=comments.contribution.js.map