import { Disposable, Event, IDisposable, IRange, URI } from '@opensumi/ide-core-browser';
import { IEditor } from '@opensumi/ide-editor';
import { ICommentRangeProvider, ICommentsService, ICommentsThread, ICommentsThreadOptions } from '../common';
import { CommentsThread } from './comments-thread';
import { CommentContentNode, CommentFileNode, CommentReplyNode, CommentRoot } from './tree/tree-node.defined';
export declare class CommentsService extends Disposable implements ICommentsService {
    private readonly injector;
    private readonly appConfig;
    private readonly editorDecorationCollectionService;
    private readonly iconService;
    private readonly labelService;
    private readonly commentsFeatureRegistry;
    private readonly documentService;
    private readonly layoutService;
    private readonly workbenchEditorService;
    private readonly resourceService;
    private decorationChangeEmitter;
    private threads;
    private threadsChangeEmitter;
    private threadsCommentChangeEmitter;
    private threadsCreatedEmitter;
    private rangeProviderMap;
    private rangeOwner;
    private providerDecorationCache;
    private shouldShowCommentsSchemes;
    private decorationProviderDisposer;
    get commentsThreads(): ICommentsThread[];
    get isMultiCommentsForSingleLine(): boolean;
    get currentAuthorAvatar(): string | undefined;
    get filterThreadDecoration(): ((thread: ICommentsThread) => boolean) | undefined;
    get onThreadsChanged(): Event<ICommentsThread>;
    get onThreadsCommentChange(): Event<ICommentsThread>;
    get onThreadsCreated(): Event<ICommentsThread>;
    /**
     * -------------------------------- IMPORTANT --------------------------------
     * 需要注意区分 model.IModelDecorationOptions 与 monaco.editor.IModelDecorationOptions 两个类型
     * 将 model.IModelDecorationOptions 类型的对象传给签名为 monaco.editor.IModelDecorationOptions 的方法时需要做 Type Assertion
     * 这是因为 monaco.d.ts 与 vs/editor/common/model 分别导出了枚举 TrackedRangeStickiness
     * 这种情况下两个枚举的类型是不兼容的，即使他们是同一段代码的编译产物
     * -------------------------------- IMPORTANT --------------------------------
     * @param thread
     */
    private createThreadDecoration;
    private createHoverDecoration;
    init(): void;
    handleOnCreateEditor(editor: IEditor): Disposable;
    private shouldShowHoverDecoration;
    createThread(uri: URI, range: IRange, options?: ICommentsThreadOptions): CommentsThread;
    getThreadsByUri(uri: URI): ICommentsThread[];
    handleCommentFileNode(parent: CommentRoot): CommentFileNode[];
    handleCommentContentNode(parent: CommentFileNode): CommentContentNode[];
    handleCommentReplyNode(parent: CommentContentNode): CommentReplyNode[];
    resolveChildren(parent?: CommentRoot | CommentFileNode | CommentContentNode): Promise<(CommentRoot | CommentFileNode | CommentContentNode | CommentReplyNode)[]>;
    getContributionRanges(uri: URI): Promise<IRange[]>;
    fireThreadCommentChange(thread: ICommentsThread): void;
    private registerDecorationProvider;
    registerCommentPanel(): void;
    get panelBadge(): string;
    registerCommentRangeProvider(id: string, provider: ICommentRangeProvider): IDisposable;
    forceUpdateDecoration(): void;
    getProviderIdsByLine(line: number): string[];
}
//# sourceMappingURL=comments.service.d.ts.map